@@ -16,7 +16,7 @@ Test::BDD::Cucumber::Definitions::HTTP::Ru - Шаги на русском язы
 
 =cut
 
-our $VERSION = '0.21';
+our $VERSION = '0.25';
 
 ## no critic [RegularExpressions::ProhibitCaptureWithoutTest]
 ## no critic [RegularExpressions::RequireExtendedFormatting]
@@ -46,6 +46,10 @@ our $VERSION = '0.21';
 
 =head1 ШАГИ
 
+=cut
+
+sub import {
+
 =head2 Формирование запроса
 
 =pod
@@ -56,12 +60,10 @@ our $VERSION = '0.21';
 
 =cut
 
-# http request header "" set ""
-When qr/заголовок HTTP-запроса "(.+?)" установлен в значение "(.*)"/, sub {
-    my ( $header, $value ) = ( $1, $2 );
-
-    header_set( $header, $value );
-};
+    #       http request header "(.+?)" set "(.*)"
+    When qr/заголовок HTTP-запроса "(.+?)" установлен в значение "(.*)"/, sub {
+        http_request_header_set( $1, $2 );
+    };
 
 =pod
 
@@ -77,12 +79,10 @@ When qr/заголовок HTTP-запроса "(.+?)" установлен в 
 
 =cut
 
-# http request content set
-When qr/тело HTTP-запроса заполнено данными/, sub {
-    my ($content) = C->data();
-
-    content_set($content);
-};
+    #       http request content set
+    When qr/тело HTTP-запроса заполнено данными/, sub {
+        http_request_content_set( C->data() );
+    };
 
 =head2 Отправка запроса
 
@@ -95,12 +95,10 @@ When qr/тело HTTP-запроса заполнено данными/, sub {
 
 =cut
 
-# http request "" send ""
-When qr/HTTP-запрос "(.+?)" отправлен на "(.+)"/, sub {
-    my ( $method, $url ) = ( $1, $2 );
-
-    request_send( $method, $url );
-};
+    #       http request "(.+?)" send "(.+)"
+    When qr/HTTP-запрос "(.+?)" отправлен на "(.+)"/, sub {
+        http_request_send( $1, $2 );
+    };
 
 =head2 Проверка ответа
 
@@ -112,12 +110,10 @@ When qr/HTTP-запрос "(.+?)" отправлен на "(.+)"/, sub {
 
 =cut
 
-# http response code eq ""
-Then qr/код HTTP-ответа равен "(.+)"/, sub {
-    my ($code) = ($1);
-
-    code_eq($code);
-};
+    #       http response code eq "(.+)"
+    Then qr/код HTTP-ответа равен "(.+)"/, sub {
+        http_response_code_eq($1);
+    };
 
 =pod
 
@@ -127,12 +123,10 @@ Then qr/код HTTP-ответа равен "(.+)"/, sub {
 
 =cut
 
-# http response header "" eq ""
-Then qr/заголовок HTTP-ответа "(.+?)" равен "(.*)"/, sub {
-    my ( $name, $value ) = ( $1, $2 );
-
-    header_eq( $name, $value );
-};
+    #       http response header "(.+?)" eq "(.*)"
+    Then qr/заголовок HTTP-ответа "(.+?)" равен "(.*)"/, sub {
+        http_response_header_eq( $1, $2 );
+    };
 
 =pod
 
@@ -142,12 +136,10 @@ Then qr/заголовок HTTP-ответа "(.+?)" равен "(.*)"/, sub {
 
 =cut
 
-# http response header "" re ""
-Then qr/заголовок HTTP-ответа "(.+?)" совпадает с "(.+)"/, sub {
-    my ( $name, $value ) = ( $1, $2 );
-
-    header_re( $name, $value );
-};
+    #       http response header "(.+?)" re "(.+)"
+    Then qr/заголовок HTTP-ответа "(.+?)" совпадает с "(.+)"/, sub {
+        http_response_header_re( $1, $2 );
+    };
 
 =pod
 
@@ -157,12 +149,10 @@ Then qr/заголовок HTTP-ответа "(.+?)" совпадает с "(.+)
 
 =cut
 
-# http response content eq ""
-Then qr/содержимое HTTP-ответа равно "(.*)"/, sub {
-    my ($value) = ($1);
-
-    content_eq($value);
-};
+    #       http response content eq "(.*)"
+    Then qr/содержимое HTTP-ответа равно "(.*)"/, sub {
+        http_response_content_eq($1);
+    };
 
 =pod
 
@@ -172,12 +162,13 @@ Then qr/содержимое HTTP-ответа равно "(.*)"/, sub {
 
 =cut
 
-# http response content re ""
-Then qr/содержимое HTTP-ответа совпадает с "(.+)"/, sub {
-    my ($value) = ($1);
+    #       http response content re "(.+)"
+    Then qr/содержимое HTTP-ответа совпадает с "(.+)"/, sub {
+        http_response_content_re($1);
+    };
 
-    content_re($value);
-};
+    return;
+}
 
 1;
 
