@@ -5,12 +5,11 @@ use warnings;
 
 use DDP ( show_unicode => 1 );
 use Exporter qw(import);
-use Params::ValidationCompiler qw(validation_for);
 use Test::BDD::Cucumber::Definitions qw(S);
-use Test::BDD::Cucumber::Definitions::Types qw(:all);
+use Test::BDD::Cucumber::Definitions::Validator qw(:all);
 use Test::More;
 
-our $VERSION = '0.21';
+our $VERSION = '0.25';
 
 our @EXPORT_OK = qw(
     var_scenario_var_set
@@ -27,42 +26,20 @@ our %EXPORT_TAGS = (
 
 ## no critic [Subroutines::RequireArgUnpacking]
 
-my $validator_var_set = validation_for(
-    params => [
-
-        # var name
-        { type => TbcdNonEmptyStr },
-
-        # var value
-        { type => TbcdStr }
-    ]
-);
-
 sub var_scenario_var_set {
-    my ( $name, $value ) = $validator_var_set->(@_);
+    my ( $name, $value ) = validator_ns->(@_);
 
     S->{var}->{scenario}->{vars}->{$name} = $value;
 
     return;
 }
 
-my $validator_var_random = validation_for(
-    params => [
-
-        # var name
-        { type => TbcdNonEmptyStr },
-
-        # var length
-        { type => TbcdInt }
-    ]
-);
-
 sub var_scenario_var_random {
-    my ( $name, $length ) = $validator_var_random->(@_);
+    my ( $name, $length ) = validator_ni->(@_);
 
     my @CHARS = ( 'a' .. 'z', 'A' .. 'Z', 0 .. 9 );
     my $str = "X" x $length;
-    $str =~ s/X(?=X*\z)/$CHARS[ int( rand( @CHARS ) ) ]/ge;
+    $str =~ s/X(?=X*\z)/$CHARS[ int( rand( @CHARS ) ) ]/gex;
 
     S->{var}->{scenario}->{vars}->{$name} = $str;
 
