@@ -7,6 +7,12 @@ use utf8;
 use Test::BDD::Cucumber::Definitions qw(Given When Then);
 use Test::BDD::Cucumber::Definitions::Zip qw(:util);
 
+our $VERSION = '0.25';
+
+## no critic [RegularExpressions::ProhibitCaptureWithoutTest]
+## no critic [RegularExpressions::RequireExtendedFormatting]
+## no critic [RegularExpressions::ProhibitComplexRegexes]
+
 =encoding utf8
 
 =head1 NAME
@@ -14,14 +20,6 @@ use Test::BDD::Cucumber::Definitions::Zip qw(:util);
 Test::BDD::Cucumber::Definitions::Zip::Ru - Шаги на русском языке
 для работы с архивами Zip
 
-=cut
-
-our $VERSION = '0.21';
-
-## no critic [RegularExpressions::ProhibitCaptureWithoutTest]
-## no critic [RegularExpressions::RequireExtendedFormatting]
-## no critic [RegularExpressions::ProhibitComplexRegexes]
-
 =head1 SYNOPSIS
 
 В файле B<features/step_definitions/zip_steps.pl>:
@@ -54,6 +52,10 @@ our $VERSION = '0.21';
 
 =head1 ШАГИ
 
+=cut
+
+sub import {
+
 =head2 Чтение данных
 
 =pod
@@ -65,10 +67,13 @@ our $VERSION = '0.21';
 
 =cut
 
-# http response content read Zip
-When qr/содержимое HTTP-ответа прочитано как Zip/, sub {
-    read_content();
-};
+    #       http response content read Zip
+    When qr/содержимое HTTP-ответа прочитано как Zip/, sub {
+        http_response_content_read_zip();
+    };
+
+    return;
+}
 
 1;
 
